pub struct CustomerManagedEncryptionStatus {
pub kms_key_version_name: Option<String>,
}Expand description
Describes the status of customer-managed encryption.
This type is not used in any activity, and only used as part of another schema.
Fields
kms_key_version_name: Option<String>Required. The resource name of the Cloud KMS CryptoKeyVersion used to encrypt the secret payload, in the following format: projects/*/locations/*/keyRings/*/cryptoKeys/*/versions/*.