pub struct Replica {
pub customer_managed_encryption: Option<CustomerManagedEncryption>,
pub location: Option<String>,
}Expand description
Represents a Replica for this Secret.
This type is not used in any activity, and only used as part of another schema.
Fields
customer_managed_encryption: Option<CustomerManagedEncryption>Optional. The customer-managed encryption configuration of the User-Managed Replica. If no configuration is provided, Google-managed default encryption is used. Updates to the Secret encryption configuration only apply to SecretVersions added afterwards. They do not apply retroactively to existing SecretVersions.
location: Option<String>The canonical IDs of the location to replicate data. For example: "us-east1".