pub struct ReplicationStatus {
pub automatic: Option<AutomaticStatus>,
pub user_managed: Option<UserManagedStatus>,
}Expand description
The replication status of a SecretVersion.
This type is not used in any activity, and only used as part of another schema.
Fields
automatic: Option<AutomaticStatus>Describes the replication status of a SecretVersion with automatic replication. Only populated if the parent Secret has an automatic replication policy.
user_managed: Option<UserManagedStatus>Describes the replication status of a SecretVersion with user-managed replication. Only populated if the parent Secret has a user-managed replication policy.