pub struct SecretVersion {
pub client_specified_payload_checksum: Option<bool>,
pub create_time: Option<DateTime<Utc>>,
pub customer_managed_encryption: Option<CustomerManagedEncryptionStatus>,
pub destroy_time: Option<DateTime<Utc>>,
pub etag: Option<String>,
pub name: Option<String>,
pub replication_status: Option<ReplicationStatus>,
pub scheduled_destroy_time: Option<DateTime<Utc>>,
pub state: Option<String>,
}Expand description
A secret version resource in the Secret Manager API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations secrets versions destroy projects (response)
- locations secrets versions disable projects (response)
- locations secrets versions enable projects (response)
- locations secrets versions get projects (response)
- locations secrets add version projects (response)
- secrets versions destroy projects (response)
- secrets versions disable projects (response)
- secrets versions enable projects (response)
- secrets versions get projects (response)
- secrets add version projects (response)
Fields
client_specified_payload_checksum: Option<bool>Output only. True if payload checksum specified in SecretPayload object has been received by SecretManagerService on SecretManagerService.AddSecretVersion.
create_time: Option<DateTime<Utc>>Output only. The time at which the SecretVersion was created.
customer_managed_encryption: Option<CustomerManagedEncryptionStatus>Output only. The customer-managed encryption status of the SecretVersion. Only populated if customer-managed encryption is used and Secret is a regionalized secret.
destroy_time: Option<DateTime<Utc>>Output only. The time this SecretVersion was destroyed. Only present if state is DESTROYED.
etag: Option<String>Output only. Etag of the currently stored SecretVersion.
name: Option<String>Output only. The resource name of the SecretVersion in the format projects/*/secrets/*/versions/*. SecretVersion IDs in a Secret start at 1 and are incremented for each subsequent version of the secret.
replication_status: Option<ReplicationStatus>The replication status of the SecretVersion.
scheduled_destroy_time: Option<DateTime<Utc>>Optional. Output only. Scheduled destroy time for secret version. This is a part of the Delayed secret version destroy feature. For a Secret with a valid version destroy TTL, when a secert version is destroyed, version is moved to disabled state and it is scheduled for destruction Version is destroyed only after the scheduled_destroy_time.
state: Option<String>Output only. The current state of the SecretVersion.