Struct google_secretmanager1::api::EnableSecretVersionRequest [−][src]
Request message for SecretManagerService.EnableSecretVersion.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- secrets versions enable projects (request)