pub struct Topic {
pub name: Option<String>,
}Expand description
A Pub/Sub topic which Secret Manager will publish to when control plane events occur on this secret.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Identifier. The resource name of the Pub/Sub topic that will be published to, in the following format: projects/*/topics/*. For publication to succeed, the Secret Manager service agent must have the pubsub.topic.publish permission on the topic. The Pub/Sub Publisher role (roles/pubsub.publisher) includes this permission.